
## installmseide5104.sh

## Recommended usage: LC_ALL=C sh installmseide5104.sh 2> installmseide5104.err | tee installmseide5104.out

## Downloads, builds and installs MSEide 5.10.4 under Linux.

## The script creates two shortcuts: the one on the desktop, the other in the applications menu.
## The files stay where they have been extracted (in the script's directory).

## When you run MSEide for the first time, you must go to Settings/Configure MSEide and select the mseide5104 folder as value for the MSEDIR variable.

URL=https://github.com/mse-org/mseide-msegui/archive/refs/tags/5.10.4.zip
SCRIPT="$(realpath -s "$0")"
SCRIPTPATH="$(dirname "$SCRIPT")"
UNITS=$SCRIPTPATH/units
REVISION="5104"
## Base name for desktop files
BASENAME="mseide$REVISION"
## Application full name
APP="MSEide 5.10.4"
## Script directory
SCRDIR="$(dirname "$(readlink -f "$0")")"
## Desktop directory
DDIR="$HOME/Desktop"
## Applications menu directory
ADIR="$HOME/.local/share/applications"

echo "INFO Download"

wget --no-verbose -O 5.10.4.zip $URL

echo "INFO Unzip"

if [ ! -f "5.10.4.zip" ]; then
  echo "ERROR 5.10.4.zip does not exist."
  exit 0
fi

unzip -q 5.10.4.zip -d $SCRIPTPATH

echo "INFO Rename folder"

if [ ! -d "$SCRIPTPATH/mseide-msegui-5.10.4" ]; then
  echo "ERROR $SCRIPTPATH/mseide-msegui-5.10.4 does not exist."
  exit 0
fi

mv $SCRIPTPATH/mseide-msegui-5.10.4 $SCRIPTPATH/mseide5104

echo "INFO Build MSEide"

mkdir -p $UNITS

pushd $SCRIPTPATH/mseide5104/apps/ide/

fpc -omseide \
-Fu../../lib/common/* \
-Fu../../lib/common/kernel \
-Fi../../lib/common/kernel \
-Fu../../lib/common/kernel/linux \
-Fu../../lib/addon/* \
-Fi../../lib/addon/* \
-FU$UNITS \
-l -Mobjfpc -Sh -XX -Xs -CX -B \
mseide.pas

popd

echo "INFO Create .desktop"

if [ ! -d $DDIR ] ;
then
  echo "WARNING Cannot find $DDIR"
  DDIR="$HOME/Bureau"
fi

if [ -d $DDIR ] ;
then
  FILE=$DDIR/$BASENAME.desktop
  echo "INFO Create $FILE"
  cat > $FILE << EOF
[Desktop Entry]
Version=1.0
Type=Application
Name=$APP
Comment=Pascal IDE
Exec=$SCRDIR/$BASENAME/apps/ide/mseide --globstatfile=$SCRDIR/$BASENAME/apps/ide/mseide.sta %F
Icon=$SCRDIR/$BASENAME/msegui_64.png
Path=$SCRDIR/$BASENAME/apps/ide
Terminal=false
StartupNotify=true
Categories=Application;IDE;Development;GUIDesigner;Programming;
Keywords=editor;Pascal;IDE;FreePascal;fpc;Design;Designer;
EOF
  echo "INFO Set permission"
  sudo chmod -R 777 $FILE
  echo "INFO Done"
else
  echo "ERROR Cannot find $DDIR"
  exit 0
fi

echo "INFO Copy .desktop to applications menu directory"

if [ -d $ADIR ] ;
then
  FILE1=$DDIR/$BASENAME.desktop
  FILE2=$ADIR/$BASENAME.desktop
  echo "INFO Create $FILE2"
  cp -f $FILE1 $FILE2
  echo "INFO Set permission"
  sudo chmod -R 777 $FILE2
  echo "INFO Done"
else
  echo "ERROR Cannot find $ADIR"
  exit 0
fi
